Matrix3x2

Struct Matrix3x2 

#[repr(C)]
pub struct Matrix3x2 { pub m11: f32, pub m12: f32, pub m21: f32, pub m22: f32, pub m31: f32, pub m32: f32, }

Fields

m11: f32m12: f32m21: f32m22: f32m31: f32m32: f32

Implementations

Source

impl Matrix3x2

pub const fn identity() -> Self

Returns the identity matrix (no transform).

pub const fn translation(x: f32, y: f32) -> Self

Returns a matrix that translates by (x, y).

pub fn rotation(angle: f32) -> Self

Returns a matrix that rotates by angle degrees about the origin.

pub fn rotation_around(angle: f32, center: Vector2) -> Self

Returns a matrix that rotates by angle degrees about center.

pub fn scale(scale_x: f32, scale_y: f32) -> Self

Returns a matrix that scales by scale_x and scale_y about the origin.

pub fn scale_around(scale_x: f32, scale_y: f32, center: Vector2) -> Self

Returns a matrix that scales by scale_x and scale_y about center.

pub fn skew(angle_x: f32, angle_y: f32) -> Self

Returns a matrix that skews by angle_x and angle_y degrees about the origin.

pub fn skew_around(angle_x: f32, angle_y: f32, center: Vector2) -> Self

Returns a matrix that skews by angle_x and angle_y degrees about center.