#[repr(C)]pub struct Matrix4x4 {}Fields
m11: f32m12: f32m13: f32m14: f32m21: f32m22: f32m23: f32m24: f32m31: f32m32: f32m33: f32m34: f32m41: f32m42: f32m43: f32m44: f32Implementations
Sourceimpl Matrix4x4
impl Matrix4x4
Sourcepub const fn translation(x: f32, y: f32, z: f32) -> Self
pub const fn translation(x: f32, y: f32, z: f32) -> Self
Returns a matrix that translates by (x, y, z).
Sourcepub fn rotation_y(degree: f32) -> Self
pub fn rotation_y(degree: f32) -> Self
Returns a matrix that rotates by degree degrees about the y-axis.
Sourcepub fn perspective_projection(depth: f32) -> Self
pub fn perspective_projection(depth: f32) -> Self
Returns a perspective projection matrix for the given depth. A
non-positive depth produces no perspective foreshortening.