#[repr(C)]pub struct Vector2 {
pub x: f32,
pub y: f32,
}Fields
x: f32y: f32Implementations
Sourceimpl Vector2
impl Vector2
Sourcepub fn length_squared(&self) -> f32
pub fn length_squared(&self) -> f32
Returns the squared length of the vector, avoiding the square root
computed by length.
Sourcepub fn distance(&self, value: &Self) -> f32
pub fn distance(&self, value: &Self) -> f32
Returns the distance between the points self and value.
Sourcepub fn distance_squared(&self, value: &Self) -> f32
pub fn distance_squared(&self, value: &Self) -> f32
Returns the squared distance between the points self and value.