#[repr(C)]pub struct Vector4 {
pub x: f32,
pub y: f32,
pub z: f32,
pub w: f32,
}Fields
x: f32y: f32z: f32w: f32Implementations
Sourceimpl Vector4
impl Vector4
Sourcepub fn new(x: f32, y: f32, z: f32, w: f32) -> Self
pub fn new(x: f32, y: f32, z: f32, w: f32) -> Self
Creates a vector from its x, y, z, and w components.
Sourcepub fn length_squared(&self) -> f32
pub fn length_squared(&self) -> f32
Returns the squared length of the vector, avoiding the square root
computed by length.
Sourcepub fn distance(&self, value: &Self) -> f32
pub fn distance(&self, value: &Self) -> f32
Returns the distance between the points self and value.
Sourcepub fn distance_squared(&self, value: &Self) -> f32
pub fn distance_squared(&self, value: &Self) -> f32
Returns the squared distance between the points self and value.